@@ -1,22 +1,23 @@
 /**
+ *	This file is part of devilspie2
+ *	Copyright (C) 2011-2012 Andreas Rönnquist
  *
- *	This file is part of devilspie2.
- *	Copyright 2011 Andreas Rönnquist
- *
- *	devilspie2 is free software: you can redistribute it and/or modify
- *	it under the terms of the GNU Lesser General Public License as published by
- *	the Free Software Foundation, either version 3 of the License, or
+ *	devilspie2 is free software: you can redistribute it and/or 
+ *	modify it under the terms of the GNU General Public License as published 
+ *	by the Free Software Foundation, either version 3 of the License, or
  *	(at your option) any later version.
- *
+ * 
  *	devilspie2 is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
  *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU Lesser General Public License for more details.
- *
- *	You should have received a copy of the GNU Lesser General Public License
- *	along with devilspie2.  If not, see <http://www.gnu.org/licenses/>.
- *
+ *	GNU General Public License for more details.
+ * 
+ *	You should have received a copy of the GNU General Public License
+ *	along with devilspie2.  
+ *	If not, see <http://www.gnu.org/licenses/>.
  */
+
+
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/libwnck.h>
 
@@ -26,6 +27,14 @@
 #include <lualib.h>
 #include <lauxlib.h>
 
+#include <locale.h>
+
+#include <libintl.h>
+#define _(String) gettext (String)
+#define gettext_noop(String) String
+#define N_(String) gettext_noop (String)
+
+
 #include "script.h"
 
 #include "script_functions.h"
@@ -98,6 +107,12 @@ void register_cfunctions()
 	lua_register(lua,"unpin_window",c_unpin_window);
 	lua_register(lua,"stick_window",c_stick_window);
 	lua_register(lua,"unstick_window",c_unstick_window);
+	
+	lua_register(lua,"get_window_geometry",c_get_window_geometry);
+	lua_register(lua,"get_window_client_geometry",c_get_client_window_geometry);
+	
+	lua_register(lua,"set_skip_tasklist",c_set_skip_tasklist);
+	lua_register(lua,"set_skip_pager",c_set_skip_pager);
 }
 
 
@@ -109,7 +124,7 @@ int load_script(char *filename)
 	
 	int result=luaL_loadfile(lua,filename);
 	
-	if (result==0) {
+	if (!result) {
 		script_loaded=TRUE;
 	} else {
 		
@@ -132,7 +147,7 @@ void run_script()
 {
 	int s = lua_pcall( lua, 0, LUA_MULTRET, 0 );
 
-	if( s != 0 ) {
+	if (s) {
 	
 		char *error_msg;
 
@@ -149,7 +164,8 @@ void run_script()
 		throw( ScriptException( mssOut.str().c_str(), errorMsg ) );
 		*/
 		
-		printf("Error:%s\n",error_msg);
+		printf(_("Error: %s"),error_msg);
+		printf("\n");
 	}
 }
 
@@ -159,7 +175,7 @@ void run_script()
  */
 void done_script()
 {
-	if (lua!=NULL)
+	if (lua)
 		lua_close(lua);
 	
 	lua=NULL;
